@@ -13,7 +13,7 @@ class GetEngine(BaseEngine):
     """
 
     def _get_headers(self) -> dict:
-        return {'accept': 'application/json'}
+        return {"accept": "application/json"}
 
 
 class ThreatsSearch(GetEngine):
@@ -22,7 +22,7 @@ class ThreatsSearch(GetEngine):
     """
 
     def _build_url(self, endpoint_config: dict, environment: str):
-        return self._build_url_for_endpoint('threats')
+        return self._build_url_for_endpoint("threats")
 
     def get_json(self, list_threats: list):
         """
@@ -31,25 +31,31 @@ class ThreatsSearch(GetEngine):
         """
         terminal_size = Endpoint._get_terminal_size()
         total_hash = len(list_threats)
-        dict_threat = {'count': total_hash, 'results': []}
+        dict_threat = {"count": total_hash, "results": []}
         list_of_lost_hashes = []
         for index, threat in enumerate(list_threats):
             request_url = self.url + threat
             response_dict = self.datalake_requests(
                 request_url,
-                'get',
+                "get",
                 self._get_headers(),
                 None,
             )
             final_dict = response_dict
-            if not response_dict.get('hashkey'):
+            if not response_dict.get("hashkey"):
                 list_of_lost_hashes.append(threat)
-                logger.info(f'{str(index).ljust(5)}:{threat.ljust(terminal_size - 11)}\x1b[0;30;41mERROR\x1b[0m')
+                logger.info(
+                    f"{str(index).ljust(5)}:{threat.ljust(terminal_size - 11)}\x1b[0;30;41mERROR\x1b[0m"
+                )
             else:
-                logger.info(f'{str(index).ljust(5)}:{threat.ljust(terminal_size - 10)}\x1b[0;30;42m OK \x1b[0m')
-                response_dict = self.datalake_requests(f'{request_url}/comments', 'get', self._get_headers(), None)
-                final_dict['comments'] = response_dict
-                dict_threat['results'].append(final_dict)
+                logger.info(
+                    f"{str(index).ljust(5)}:{threat.ljust(terminal_size - 10)}\x1b[0;30;42m OK \x1b[0m"
+                )
+                response_dict = self.datalake_requests(
+                    f"{request_url}/comments", "get", self._get_headers(), None
+                )
+                final_dict["comments"] = response_dict
+                dict_threat["results"].append(final_dict)
         return dict_threat, list_of_lost_hashes
 
 
@@ -59,13 +65,15 @@ class Threats(GetEngine):
     """
 
     def _build_url(self, endpoint_config: dict, environment: str):
-        return self._build_url_for_endpoint('advanced-search')
+        return self._build_url_for_endpoint("advanced-search")
 
-    def get_threats(self, query_hash: str, limit=10, response_format="application/json") -> dict:
+    def get_threats(
+        self, query_hash: str, limit=10, response_format="application/json"
+    ) -> dict:
         url = self.url + query_hash
-        params = {'limit': limit}
+        params = {"limit": limit}
         req = PreparedRequest()  # Adding parameters using requests' tool
         req.prepare_url(url, params)
-        headers = {'Accept': response_format}
-        response = self.datalake_requests(req.url, 'get', headers=headers)
+        headers = {"Accept": response_format}
+        response = self.datalake_requests(req.url, "get", headers=headers)
         return response
