@@ -10,27 +10,29 @@ def main(override_args=None):
     """Method to start the script"""
 
     # Load initial args
-    parser = BaseScripts.start('Add tags and/or comments to a specified list of hashkeys.')
-    parser.add_argument(
-        'hashkeys',
-        help='hashkeys of the threat to add tags and/or the comment',
-        nargs='*',
+    parser = BaseScripts.start(
+        "Add tags and/or comments to a specified list of hashkeys."
     )
     parser.add_argument(
-        '-i',
-        '--input_file',
-        help='hashkey txt file, with one hashkey by line',
+        "hashkeys",
+        help="hashkeys of the threat to add tags and/or the comment",
+        nargs="*",
     )
     parser.add_argument(
-        '-p',
-        '--public',
-        help='set the visibility to public',
-        action='store_true',
+        "-i",
+        "--input_file",
+        help="hashkey txt file, with one hashkey by line",
     )
     parser.add_argument(
-        '--tags',
-        nargs='+',
-        help='add a list of tags',
+        "-p",
+        "--public",
+        help="set the visibility to public",
+        action="store_true",
+    )
+    parser.add_argument(
+        "--tags",
+        nargs="+",
+        help="add a list of tags",
         required=True,
     )
 
@@ -48,17 +50,12 @@ def main(override_args=None):
         retrieve_hashkeys_from_file(args.input_file, hashkeys)
 
     dtl = Datalake(env=args.env, log_level=args.loglevel)
-    response_dict = post_tags(
-        hashkeys,
-        args.tags,
-        args.public,
-        dtl
-    )
+    response_dict = post_tags(hashkeys, args.tags, args.public, dtl)
 
     if args.output:
         save_output(args.output, response_dict)
-        logger.debug(f'Results saved in {args.output}\n')
-    logger.debug(f'END: add_tags.py')
+        logger.debug(f"Results saved in {args.output}\n")
+    logger.debug(f"END: add_tags.py")
 
 
 def post_tags(hashkeys, tags, public, dtl):
@@ -67,21 +64,21 @@ def post_tags(hashkeys, tags, public, dtl):
         try:
             dtl.Tags.add_to_threat(hashkey, tags, public)
         except ValueError as e:
-            logger.warning('\x1b[6;30;41m' + hashkey + ': FAILED\x1b[0m')
-            logger.debug('\x1b[6;30;41m' + hashkey + ': FAILED : ' + str(e) + '\x1b[0m')
-            return_value.append(hashkey + ': FAILED')
+            logger.warning("\x1b[6;30;41m" + hashkey + ": FAILED\x1b[0m")
+            logger.debug("\x1b[6;30;41m" + hashkey + ": FAILED : " + str(e) + "\x1b[0m")
+            return_value.append(hashkey + ": FAILED")
         else:
-            return_value.append(hashkey + ': OK')
-            logger.info('\x1b[6;30;42m' + hashkey + ': OK\x1b[0m')
+            return_value.append(hashkey + ": OK")
+            logger.info("\x1b[6;30;42m" + hashkey + ": OK\x1b[0m")
     return return_value
 
 
 def retrieve_hashkeys_from_file(input_file, hashkeys):
-    with open(input_file, 'r') as input_file:
+    with open(input_file, "r") as input_file:
         for line in input_file:
             if line:
                 hashkeys.add(line.strip())
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(main())
